<?php

namespace Btravel\Externalshipdatum\Providers;

use Illuminate\Support\ServiceProvider;

class ExternalshipdatumServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'externalshipdatum');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'externalshipdatum');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerExternalshipdatum();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerExternalshipdatum()
    {
        $this->app->bind('externalshipdatum', function($app) {
            return new Externalshipdatum($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Externalshipdatum', 'Lavalite\Externalshipdatum\Facades\Externalshipdatum');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('btravel.externalshipdatum', function ($app) {
            return $this->app->make('Btravel\Externalshipdatum\Externalshipdatum');
        });

                // Bind ExternalShipdata to repository
        $this->app->bind(
            'Btravel\Externalshipdatum\Interfaces\ExternalShipdataRepositoryInterface',
            \Btravel\Externalshipdatum\Repositories\Eloquent\ExternalShipdataRepository::class
        );

        $this->app->register(\Btravel\Externalshipdatum\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Btravel\Externalshipdatum\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and externalshipdatum's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/externalshipdatum.php', 'externalshipdatum'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeExternalshipdatum::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['btravel.externalshipdatum'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('btravel/externalshipdatum.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/externalshipdatum')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/externalshipdatum')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
